@@ -39,6 +39,10 @@ class Query():
         if condition[1] in ["in"]:
             condition[0],condition[2] = condition[2],condition[0]
             string_operator = True
+        condition_pos_0 = condition[0].split(".")
+        _list = False
+        if "*" in condition_pos_0:
+            _list = True
         for q in self.data:
             _subQ_para = condition[0].split(".")
             if len(_subQ_para) > 1:
@@ -50,10 +54,17 @@ class Query():
                     except:
                         pass
                 sub_condition = [_subQ_para[-1]]+condition[1:]
-                try:
-                    exec(self.__build_query(q=q,sub_q=sub_q,condition=sub_condition,string_operator=string_operator))
-                except:
-                    pass
+                if isinstance(sub_q,list) and _list == True:
+                    for _sub_q in sub_q:
+                        try:
+                            exec(self.__build_query(q=q,sub_q=_sub_q,condition=sub_condition,string_operator=string_operator))
+                        except:
+                            pass
+                else:
+                    try:
+                        exec(self.__build_query(q=q,sub_q=sub_q,condition=sub_condition,string_operator=string_operator))
+                    except:
+                        pass
             else:
                 try:
                     exec(self.__build_query(q=q,condition=condition,string_operator=string_operator))
@@ -62,10 +73,10 @@ class Query():
         return Query(self.out)
     
     def get(self,key):
-        filter = []
-        for i in self.data:
-            filter.append(i[key])
-        return filter
+        de = []
+        for d in self.data:
+            de.append(d[key])
+        return de
 
     def tolist(self,limit=None):
         if isinstance(limit, int):
